dart_logz library
A stupid simple logging package for Dart with colorful output.
Classes
- Logz
- A logging utility that provides color-coded log messages for different log levels such as info, success, warning, error, debug, and fatal.
- LogzConfig
- Configuration options for the Logz logging utility.